@@ -6,12 +6,37 @@ use utf8;
 use Role::Tiny::With;
 with 'TableDataRole::Source::CSVInDATA';
 
-our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2023-02-05'; # DATE
-our $DIST = 'TableData-Chemistry-Element'; # DIST
-our $VERSION = '0.002'; # VERSION
+sub get_table_spec {
+    return +{
+        fields => {
+            atomic_number => {pos=>0, schema=>'posint*'},
+            symbol        => {pos=>1, schema=>'str*'},
+            eng_name      => {pos=>2, schema=>'str*'},
+            ind_name      => {pos=>3, schema=>'str*'},
+            name_origin   => {pos=>4, schema=>'str*'},
+            group         => {pos=>5, schema=>'str*'},
+            period        => {pos=>6, schema=>'str*'},
+            block         => {pos=>7, schema=>'str*'},
+            standard_atomic_weight => {pos=>8, schema=>'float*'},
+            density       => {pos=>9, schema=>'float*'},
+            melting_point => {pos=>10, schema=>'float*'},
+            boiling_point => {pos=>11, schema=>'float*'},
+            specific_heat_capacity => {pos=>12, schema=>'float*'},
+            electronegativity => {pos=>13, schema=>'float*'},
+            abundance_in_earth_crust => {pos=>14, schema=>'str*'},
+            origin        => {pos=>15, schema=>'str*'},
+            phase_at_rt   => {pos=>16, schema=>'str*'},
+        },
+        pk => 'atomic_number',
+    };
+}
 
-our %STATS = ("num_rows",118,"num_columns",17); # STATS
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2023-02-12'; # DATE
+our $DIST = 'TableData-Chemistry-Element'; # DIST
+our $VERSION = '0.003'; # VERSION
+
+our %STATS = ("num_columns",17,"num_rows",118); # STATS
 
 1;
 # ABSTRACT: Chemical elements
@@ -26,7 +51,7 @@ TableData::Chemistry::Element - Chemical elements
 
 =head1 VERSION
 
-This document describes version 0.002 of TableData::Chemistry::Element (from Perl distribution TableData-Chemistry-Element), released on 2023-02-05.
+This document describes version 0.003 of TableData::Chemistry::Element (from Perl distribution TableData-Chemistry-Element), released on 2023-02-12.
 
 =head1 SYNOPSIS
 
@@ -69,6 +94,8 @@ See the L<tabledata> CLI's documentation for other available actions and options
 
 The statistics is available in the C<%STATS> package variable.
 
+=for Pod::Coverage ^(get_table_spec)$
+
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/TableData-Chemistry-Element>.
